<?php
/**
 * Plugin Name:  Venissa Kit
 * Plugin URI:   https://www.theme-junkie.com/themes/venissa/
 * Description:  Adds extra features to Venissa WordPress themes.
 * Version:      1.0.0
 * Author:       Theme Junkie
 * Author URI:   https://www.theme-junkie.com/
 * Author Email: support@theme-junkie.com
 * Text Domain:  venissa-kit
 * Domain Path:  /languages
 * License:      GPL 2.0
 * License URI:  http://www.gnu.org/licenses/gpl-2.0.html
 */

// Exit if accessed directly
if ( ! defined( 'ABSPATH' ) ) exit;

if ( ! class_exists( 'Venissa_Kit' ) ) {

	class Venissa_Kit {

		/**
		 * PHP5 constructor method.
		 */
		public function __construct() {

			// Set the constants needed by the plugin.
			add_action( 'plugins_loaded', array( &$this, 'constants' ), 1 );

			// Internationalize the text strings used.
			add_action( 'plugins_loaded', array( &$this, 'i18n' ), 2 );

			// Load the admin files.
			add_action( 'plugins_loaded', array( &$this, 'admin' ), 3 );

			// Load the functions files.
			add_action( 'plugins_loaded', array( &$this, 'includes' ), 4 );

			// Enqueue the front-end styles and scripts.
			add_action( 'wp_enqueue_scripts', array( &$this, 'plugin_assets' ), 99 );

		}

		/**
		 * Defines constants used by the plugin.
		 */
		public function constants() {

			// Set constant path to the plugin directory.
			define( 'BK_DIR', trailingslashit( plugin_dir_path( __FILE__ ) ) );

			// Set the constant path to the plugin directory URI.
			define( 'BK_URI', trailingslashit( plugin_dir_url( __FILE__ ) ) );

			// Set the constant path to the admin directory.
			define( 'BK_ADMIN', BK_DIR . trailingslashit( 'admin' ) );

			// Set the constant path to the inc directory.
			define( 'BK_INCLUDES', BK_DIR . trailingslashit( 'inc' ) );

			// Set the constant path to the assets directory.
			define( 'BK_ASSETS', BK_URI . trailingslashit( 'assets' ) );

		}

		/**
		 * Loads the translation files.
		 */
		public function i18n() {
			load_plugin_textdomain( 'venissa-kit', false, dirname( plugin_basename( __FILE__ ) ) . '/languages/' );
		}

		/**
		 * Loads the initial files for the admin area.
		 */
		public function admin() {
			require_once( BK_ADMIN . 'customizer.php' );
			require_once( BK_ADMIN . 'sanitize.php' );
		}

		/**
		 * Loads the initial files needed by the plugin.
		 */
		public function includes() {
			require_once( BK_INCLUDES . 'author-profile-social.php' );
			require_once( BK_INCLUDES . 'cookie.php' );
			// require_once( BK_INCLUDES . 'sticky-sidebar.php' );
			require_once( BK_INCLUDES . 'pinterest.php' );
			require_once( BK_INCLUDES . 'signature.php' );
		}

		/**
		 * Enqueue front-end styles and scripts.
		 */
		public function plugin_assets() {
			wp_enqueue_style( 'venissa-kit-css', BK_ASSETS . 'css/venissa.css' );
			wp_enqueue_script( 'venissa-kit-js', BK_ASSETS . 'js/venissa.min.js', array( 'jquery' ), null, true );
			wp_enqueue_script( 'venissa-kit-custom-js', BK_ASSETS . 'js/venissa-custom.js', array( 'jquery' ), null, true );
		}

	}

}

new Venissa_Kit;
