( function( $ ) {

	// Document ready
	$( function() {

		/*
		 * The following code deals with the custom media modal frame for the header image.  It is a
		 * modified version of Thomas Griffin's New Media Image Uploader example plugin
		 * and Justin Tadlock code in Custom Header Extended plugin
		 *
		 * @link      https://github.com/thomasgriffin/New-Media-Image-Uploader
		 * @license   http://www.opensource.org/licenses/gpl-license.php
		 * @author    Thomas Griffin <thomas@thomasgriffinmedia.com>
		 * @copyright Copyright 2013 Thomas Griffin
		 */
		var venissa_category_image_frame;

		$( '.category-image-open' ).on( 'click', function( e ) {

			// Prevent the default link behavior.
			e.preventDefault();

			// If the frame already exists, open it.
			if ( venissa_category_image_frame ) {
				venissa_category_image_frame.open();
				return;
			}

			// Creates a custom media frame.
			venissa_category_image_frame = wp.media.frames.venissa_category_image_frame = wp.media( {
				className: 'media-frame', // Custom CSS class name
				frame: 'select', // Frame type (post, select)
				multiple: false, // Allow selection of multiple images
				title: venissa_category_image.title, // Custom frame title

				library: {
					type: 'image' // Media types allowed
				},

				button: {
					text: venissa_category_image.button // Custom insert button text
				}
			} );

			/*
			 * The following handles the image data and sending it back to the meta box once an
			 * an image has been selected via the media frame.
			 */
			venissa_category_image_frame.on( 'select', function() {

				// Construct a JSON representation of the model.
				var media_attachment = venissa_category_image_frame.state().get( 'selection' ).toJSON();

				// Add the image attachment ID to our hidden form field.
				$( '#venissa-category-image' ).val( media_attachment[ 0 ].id );

				// Adds a custom class to the wrapper
				$( '.category-image-wrap' ).addClass( 'image-attached' );

				// Inject the image so the image will display in the meta box.
				$( '.category-image-img' ).attr( 'src', media_attachment[ 0 ].sizes.medium.url );

			} );

			// Open up the frame
			venissa_category_image_frame.open();

		} );

		// When the 'remove image' button is clicked.
		$( '.category-image-remove' ).on( 'click', function( e ) {

			// Prevent the default link behavior.
			e.preventDefault();

			// Set the image input value to nothing.
			$( '#venissa-category-image' ).val( '' );

			// Remove a custom class to the wrapper
			$( '.category-image-wrap' ).removeClass( 'image-attached' );

			// Remove the image preview.
			$( '.category-image-img' ).removeAttr( 'src' );
		} );

	} );

}( jQuery ) );
