<?php
/**
 * Custom category meta
 */

/**
 * Register the term meta.
 */
function venissa_register_category_meta() {

	// Register 'image' meta
	register_meta( 'term', 'image', 'absint' );

}
add_action( 'init', 'venissa_register_category_meta' );

/**
 * Add new form screen term field.
 */
function venissa_add_category_custom_meta( $term ) {

	wp_nonce_field( basename( __FILE__ ), 'venissa_custom_category_form_fields_nonce' ); ?>

	<div class="form-field category-image-wrap">
		<label for="category-image-open"><?php esc_html_e( 'Image', 'venissa' ); ?></label>

		<div class="category-image-preview">
			<div class="placeholder"><?php esc_html_e( 'No Image Selected', 'venissa' ) ?></div>
			<a href="#" class="category-image-open category-image-link">
				<img class="category-image-img" src="">
			</a>
		</div>

		<div class="category-image-buttons">
			<a href="#" class="category-image-open category-image-open-button button" title="<?php esc_attr_e( 'Add Image', 'venissa' ); ?>"><?php esc_html_e( 'Add Image', 'venissa' ); ?></a>
			<a href="#" class="category-image-open category-image-change button" title="<?php esc_attr_e( 'Change Image', 'venissa' ); ?>"><?php esc_html_e( 'Change Image', 'venissa' ); ?></a>
			<a href="#" class="category-image-remove button" title="<?php esc_attr_e( 'Remove Image', 'venissa' ); ?>"><?php esc_html_e( 'Remove Image', 'venissa' ); ?></a>
		</div>

		<input type="hidden" name="venissa_category_image" id="venissa-category-image" value="" />
	</div>

<?php }
add_action( 'category_add_form_fields', 'venissa_add_category_custom_meta' );

/**
 * Edit form screen term color field.
 *
 * @since  1.0.0
 */
function venissa_edit_category_custom_meta( $term ) {

	// Nonce
	wp_nonce_field( basename( __FILE__ ), 'venissa_custom_category_form_fields_nonce' );

	// Get the image attachment ID.
	$attachment_id = get_term_meta( $term->term_id, 'image', true );

	// If an attachment ID was found, get the image source.
	if ( !empty( $attachment_id ) )
		$image = wp_get_attachment_image_src( absint( $attachment_id ), 'medium' );

	// Get the image URL.
	$url = !empty( $image ) && isset( $image[0] ) ? $image[0] : '';

	// Needed custom class
	$class = '';
	if ( !empty( $url ) ) {
		$class = 'image-attached';
	}
	?>

	<tr class="form-field category-image-wrap <?php echo sanitize_html_class( $class ); ?>">
		<th scope="row">
			<label for="category-image-open"><?php esc_html_e( 'Image', 'venissa' ); ?></label>
		</th>

		<td>
			<div class="category-image-preview">
				<div class="placeholder"><?php esc_html_e( 'No Image Selected', 'venissa' ) ?></div>
				<a href="#" class="category-image-open category-image-link">
					<img class="category-image-img" src="<?php echo esc_url( $url ); ?>">
				</a>
			</div>

			<div class="category-image-buttons">
				<a href="#" class="category-image-open category-image-open-button button" title="<?php esc_attr_e( 'Add Image', 'venissa' ); ?>"><?php esc_html_e( 'Add Image', 'venissa' ); ?></a>
				<a href="#" class="category-image-open category-image-change button" title="<?php esc_attr_e( 'Change Image', 'venissa' ); ?>"><?php esc_html_e( 'Change Image', 'venissa' ); ?></a>
				<a href="#" class="category-image-remove button" title="<?php esc_attr_e( 'Remove Image', 'venissa' ); ?>"><?php esc_html_e( 'Remove Image', 'venissa' ); ?></a>
			</div>

			<input type="hidden" name="venissa_category_image" id="venissa-category-image" value="<?php echo absint( $attachment_id ); ?>" />
		</td>

	</tr>

<?php }
add_action( 'category_edit_form_fields', 'venissa_edit_category_custom_meta' );

/**
 * Saving term
 *
 * @since  1.0.0
 * @param  int $term_id
 * @return null
 */
function venissa_save_custom_category_meta( $term_id ) {

	if ( ! isset( $_POST['venissa_custom_category_form_fields_nonce'] ) || ! wp_verify_nonce( $_POST['venissa_custom_category_form_fields_nonce'], basename( __FILE__ ) ) )
		return;

	$meta = array(
		'image' => isset( $_POST['venissa_category_image'] ) ? absint( $_POST['venissa_category_image'] ) : ''
	);

	foreach ( $meta as $meta_key => $new_meta_value ) {

		$meta_value = get_term_meta( $term_id, $meta_key, true );

		if ( $meta_value && '' === $new_meta_value )
			delete_term_meta( $term_id, $meta_key, $meta_value );

		else if ( $new_meta_value !== $meta_value )
			update_term_meta( $term_id, $meta_key, $new_meta_value );

	}
}
add_action( 'edit_category',   'venissa_save_custom_category_meta' );
add_action( 'create_category', 'venissa_save_custom_category_meta' );

/**
 * Add a new column to enabled taxonomy admin pages that show the chosen image.
 */
function venissa_edit_category_column( $columns ) {
    $columns['image'] = esc_html__( 'Image', 'venissa' );
    return $columns;
}
add_filter( 'manage_edit-category_columns', 'venissa_edit_category_column' );

/**
 * Show the selected term image within the newly created admin column.
 */
function venissa_manage_category_column( $out, $column, $term_id ) {

    if ( 'image' === $column ) {

        $attachment_id = get_term_meta( $term_id, 'image', true );
        $attachment_id = $attachment_id ? absint( $attachment_id ) : '';

        $out = wp_get_attachment_image( $attachment_id, 'thumbnail' );
    }

    return $out;
}
add_filter( 'manage_category_custom_column', 'venissa_manage_category_column', 10, 3 );

/**
 * Enqueue scripts and styles used for the custom category meta.
 */
function venissa_category_admin_enqueue_scripts( $hook_suffix ) {

	// Shows on category admin page.
	if ( 'category' !== get_current_screen()->taxonomy )
		return;

	// Register the needed script and style.
	wp_register_style( 'venissa-category-style', trailingslashit( get_template_directory_uri() ) . 'inc/category/assets/category.css' );
	wp_register_script( 'venissa-category-script', trailingslashit( get_template_directory_uri() ) . 'inc/category/assets/category.js', array( 'jquery' ), null, true );

	// Load the needed scripts and styles.
	wp_enqueue_style( 'venissa-category-style' );
	wp_enqueue_script( 'venissa-category-script' );
	wp_enqueue_media();

	// Set up variables to pass to the custom headers script.
	$localize_script = array(
		'title'  => esc_html__( 'Category Image', 'venissa' ),
		'button' => esc_html__( 'Set category image', 'venissa' ),
	);

	// Pass custom variables to the script.
	wp_localize_script( 'venissa-category-script', 'venissa_category_image', $localize_script );
}
add_action( 'admin_enqueue_scripts', 'venissa_category_admin_enqueue_scripts' );
