<?php
/**
 * Venissa Theme Customizer
 */

// Loads custom control
require trailingslashit( get_template_directory() ) . 'inc/customizer/controls/title.php';
require trailingslashit( get_template_directory() ) . 'inc/customizer/controls/radio-image.php';
require trailingslashit( get_template_directory() ) . 'inc/customizer/controls/checkbox-multiple.php';

// Loads the customizer settings
require trailingslashit( get_template_directory() ) . 'inc/customizer/options/retina-logo.php';
require trailingslashit( get_template_directory() ) . 'inc/customizer/options/general.php';
require trailingslashit( get_template_directory() ) . 'inc/customizer/options/colors.php';
require trailingslashit( get_template_directory() ) . 'inc/customizer/options/fonts.php';
require trailingslashit( get_template_directory() ) . 'inc/customizer/options/header.php';
require trailingslashit( get_template_directory() ) . 'inc/customizer/options/layouts.php';
require trailingslashit( get_template_directory() ) . 'inc/customizer/options/featured.php';
require trailingslashit( get_template_directory() ) . 'inc/customizer/options/after-featured.php';
require trailingslashit( get_template_directory() ) . 'inc/customizer/options/post.php';
require trailingslashit( get_template_directory() ) . 'inc/customizer/options/page.php';
require trailingslashit( get_template_directory() ) . 'inc/customizer/options/posts-carousel.php';
require trailingslashit( get_template_directory() ) . 'inc/customizer/options/footer.php';

/**
 * Custom customizer functions.
 */
function venissa_customize_functions( $wp_customize ) {

	// Register new panel: Venissa Options
	$wp_customize->add_panel( 'venissa_options', array(
		'title'       => esc_html__( 'Theme Options', 'venissa' ),
		'description' => esc_html__( 'This panel is used for customizing the Venissa theme.', 'venissa' ),
		'priority'    => 130,
	) );

	// Live preview of Site Title and Description
	$wp_customize->get_setting( 'blogname' )->transport        = 'postMessage';
	$wp_customize->get_setting( 'blogdescription' )->transport = 'postMessage';

	// Enable selective refresh to the Site Title
	if ( isset( $wp_customize->selective_refresh ) ) {
		$wp_customize->selective_refresh->add_partial( 'blogname', array(
			'selector'         => '.site-title a',
			'settings'         => array( 'blogname' ),
			'render_callback' => 'venissa_customize_partial_blogname',
		) );
	}

	// Enable selective refresh to the Site Description
	if ( isset( $wp_customize->selective_refresh ) ) {
		$wp_customize->selective_refresh->add_partial( 'blogdescription', array(
			'selector'         => '.site-description',
			'settings'         => array( 'blogdescription' ),
			'render_callback'  => 'venissa_customize_partial_blogdescription',
		) );
	}

	// Move the Colors section.
	$wp_customize->get_section( 'colors' )->panel    = 'venissa_options';
	$wp_customize->get_section( 'colors' )->priority = 2;

	// Move the Background Image section.
	$wp_customize->get_section( 'background_image' )->panel    = 'venissa_options';
	$wp_customize->get_section( 'background_image' )->priority = 3;
	$wp_customize->get_section( 'background_image' )->title    = esc_html__( 'Background', 'venissa' );

	// Move background color to background image section.
	$wp_customize->get_control( 'background_color' )->section = 'background_image';

}
add_action( 'customize_register', 'venissa_customize_functions', 99 );

/**
 * Render the site title for the selective refresh partial.
 *
 * @return void
 */
function venissa_customize_partial_blogname() {
	bloginfo( 'name' );
}

/**
 * Render the site tagline for the selective refresh partial.
 *
 * @return void
 */
function venissa_customize_partial_blogdescription() {
	bloginfo( 'description' );
}

/**
 * Binds JS handlers to make Theme Customizer preview reload changes asynchronously.
 */
function venissa_customize_preview_js() {
	wp_enqueue_script( 'venissa-customizer', get_template_directory_uri() . '/inc/customizer/assets/js/preview.js', array( 'customize-preview', 'jquery' ) );
}
add_action( 'customize_preview_init', 'venissa_customize_preview_js' );

/**
 * Display theme documentation on customizer page.
 */
function venissa_documentation_link() {

	// Enqueue the script
	wp_enqueue_script( 'venissa-doc', get_template_directory_uri() . '/inc/customizer/assets/js/doc.js', array(), null, true );

	// Localize the script
	wp_localize_script( 'venissa-doc', 'venissaL10n',
		array(
			'venissaURL'   => esc_url( 'https://docs.theme-junkie.com/venissa/' ),
			'venissaLabel' => esc_html__( 'Documentation', 'venissa' ),
		)
	);

}
add_action( 'customize_controls_enqueue_scripts', 'venissa_documentation_link' );

/**
 * Localize custom controls
 */
function venissa_localize_controls() {

	// Localize checkbox multiple control.
	$localize_script = array(
		'limit' => esc_html__( 'Only allowed 4 categories!', 'venissa' )
	);
	wp_localize_script( 'venissa-customize-controls', 'venissa_customize_control', $localize_script );

}
add_action( 'customize_controls_enqueue_scripts', 'venissa_localize_controls' );


/**
 * Custom RSS feed url.
 */
function venissa_custom_rss_url( $output, $feed ) {

	// Get the custom rss feed url
	$url = get_theme_mod( 'venissa_custom_rss' );

	// Do not redirect comments feed
	if ( strpos( $output, 'comments' ) ) {
		return $output;
	}

	// Check the settings.
	if ( ! empty( $url ) ) {
		$output = esc_url( $url );
	}

	return $output;
}
add_filter( 'feed_link', 'venissa_custom_rss_url', 10, 2 );
