<?php
/**
 * After Featured Posts Customizer
 */

/**
 * Register the customizer.
 */
function venissa_after_featured_posts_customize_register( $wp_customize ) {

	// Register new section: After Featured Posts
	$wp_customize->add_section( 'venissa_after_featured_posts' , array(
		'title'       => esc_html__( 'After Featured Posts', 'venissa' ),
		'description' => esc_html__( 'Content or elements after the featured posts.', 'venissa' ),
		'panel'       => 'venissa_options',
		'priority'    => 13
	) );

	// Register enable after featured posts content setting
	$wp_customize->add_setting( 'venissa_after_featured_posts_enable', array(
		'default'           => 1,
		'sanitize_callback' => 'venissa_sanitize_checkbox',
	) );
	$wp_customize->add_control( 'venissa_after_featured_posts_enable', array(
		'label'             => esc_html__( 'Show content after featured posts', 'venissa' ),
		'section'           => 'venissa_after_featured_posts',
		'priority'          => 1,
		'type'              => 'checkbox'
	) );

	// Register after featured posts content setting.
	$wp_customize->add_setting( 'venissa_after_featured_posts_content', array(
		'default'           => '',
		'sanitize_callback' => 'venissa_sanitize_select',
	) );
	$wp_customize->add_control( 'venissa_after_featured_posts_content', array(
		'label'             => esc_html__( 'Content', 'venissa' ),
		'section'           => 'venissa_after_featured_posts',
		'priority'          => 3,
		'type'              => 'radio',
		'choices'           => array(
			'featured_category' => esc_html__( 'Featured category', 'venissa' ),
			'subscribe'         => esc_html__( 'Subscribe form', 'venissa' ),
			'grid_posts'        => esc_html__( 'Grid posts', 'venissa' ),
			'promo_boxes'       => esc_html__( 'Promo Boxes', 'venissa' ),
		),
		'active_callback'   => 'venissa_is_after_featured_posts_enable'
	) );

	// Register after featured posts content setting.
	$wp_customize->add_setting( 'venissa_featured_category_layout', array(
		'default'           => 'grid',
		'sanitize_callback' => 'venissa_sanitize_select',
	) );
	$wp_customize->add_control( 'venissa_featured_category_layout', array(
		'label'             => esc_html__( 'Layout', 'venissa' ),
		'description'       => esc_html__( 'Featured category layout.', 'venissa' ),
		'section'           => 'venissa_after_featured_posts',
		'priority'          => 5,
		'type'              => 'radio',
		'choices'           => array(
			'grid'    => esc_html__( 'Grid', 'venissa' ),
			'modern'  => esc_html__( 'Modern', 'venissa' ),
		),
		'active_callback'   => 'venissa_is_featured_category_checked'
	) );

	// Pull all the categories into an array
	$categories = get_categories( array(
		'hide_empty' => false,
		'number'     => 25
	) );
	$cats = array();
	foreach( $categories as $category ){
		$cats[$category->cat_ID] = $category->name;
	}

	if ( $cats ) {

		// Register featured category setting.
		$wp_customize->add_setting( 'venissa_featured_category', array(
			'default'           => '',
			'sanitize_callback' => 'venissa_sanitize_checkbox_multiple_category'
		) );
		$wp_customize->add_control( new Venissa_Checkbox_Multiple_Control( $wp_customize, 'venissa_featured_category', array(
			'label'             => esc_html__( 'Featured Category', 'venissa' ),
			'description'       => esc_html__( 'Please select 4 featured categories.', 'venissa' ),
			'section'           => 'venissa_after_featured_posts',
			'priority'          => 7,
			'choices'           => $cats,
			'active_callback'   => 'venissa_is_featured_category_checked'
		) ) );

	}

	// Register newsletter title setting
	$wp_customize->add_setting( 'venissa_newsletter_title', array(
		'default'           => esc_html__( 'Never Miss A Post!', 'venissa' ),
		'sanitize_callback' => 'venissa_sanitize_html',
	) );
	$wp_customize->add_control( 'venissa_newsletter_title', array(
		'label'             => esc_html__( 'Title', 'venissa' ),
		'section'           => 'venissa_after_featured_posts',
		'priority'          => 9,
		'type'              => 'text',
		'active_callback'   => 'venissa_is_subscribe_checked'
	) );

	// Register newsletter description setting
	$wp_customize->add_setting( 'venissa_newsletter_desc', array(
		'default'           => esc_html__( 'Sign up and receive the latest tips via email.', 'venissa' ),
		'sanitize_callback' => 'venissa_sanitize_html',
	) );
	$wp_customize->add_control( 'venissa_newsletter_desc', array(
		'label'             => esc_html__( 'Description', 'venissa' ),
		'section'           => 'venissa_after_featured_posts',
		'priority'          => 11,
		'type'              => 'text',
		'active_callback'   => 'venissa_is_subscribe_checked'
	) );

	// Register newsletter shortcode setting
	$wp_customize->add_setting( 'venissa_newsletter_shortcode', array(
		'default'           => '',
		'sanitize_callback' => 'venissa_sanitize_html',
	) );
	$wp_customize->add_control( 'venissa_newsletter_shortcode', array(
		'label'             => esc_html__( 'Form Shortcode', 'venissa' ),
		'section'           => 'venissa_after_featured_posts',
		'priority'          => 13,
		'type'              => 'text',
		'active_callback'   => 'venissa_is_subscribe_checked'
	) );

	// Register grid posts title setting
	$wp_customize->add_setting( 'venissa_grid_posts_title', array(
		'default'           => esc_html__( 'Popular Posts', 'venissa' ),
		'sanitize_callback' => 'venissa_sanitize_html',
		'transport'         => 'postMessage',
	) );
	$wp_customize->add_control( 'venissa_grid_posts_title', array(
		'label'             => esc_html__( 'Title', 'venissa' ),
		'section'           => 'venissa_after_featured_posts',
		'priority'          => 15,
		'type'              => 'text',
		'active_callback'   => 'venissa_is_grid_posts_checked'
	) );
	if ( isset( $wp_customize->selective_refresh ) ) {
		$wp_customize->selective_refresh->add_partial( 'venissa_grid_posts_title', array(
			'selector'         => '.grid-posts-title',
			'settings'         => array( 'venissa_grid_posts_title' ),
			'render_callback'  => 'venissa_customize_partial_grid_posts_title'
		) );
	}

	// Register grid posts query setting
	$wp_customize->add_setting( 'venissa_grid_posts_query', array(
		'default'           => 'popular',
		'sanitize_callback' => 'venissa_sanitize_select'
	) );
	$wp_customize->add_control( 'venissa_grid_posts_query', array(
		'label'             => esc_html__( 'Query', 'venissa' ),
		'section'           => 'venissa_after_featured_posts',
		'priority'          => 17,
		'type'              => 'radio',
		'choices'           => array(
			'trending' => esc_html__( 'Trending', 'venissa' ),
			'recent'   => esc_html__( 'Most recent', 'venissa' ),
			'popular'  => esc_html__( 'Popular by comment', 'venissa' ),
			'random'   => esc_html__( 'Random', 'venissa' )
		),
		'active_callback'   => 'venissa_is_grid_posts_checked'
	) );

	// Register grid posts trending time setting
	$wp_customize->add_setting( 'venissa_grid_posts_time', array(
		'default'           => 'all',
		'sanitize_callback' => 'venissa_sanitize_select',
	) );
	$wp_customize->add_control( 'venissa_grid_posts_time', array(
		'label'             => esc_html__( 'Trending Time', 'venissa' ),
		'section'           => 'venissa_after_featured_posts',
		'priority'          => 19,
		'type'              => 'radio',
		'choices'           => array(
			'all'   => esc_html__( 'All time', 'venissa' ),
			'today' => esc_html__( 'Today', 'venissa' ),
			'week'  => esc_html__( 'This week', 'venissa' ),
			'month' => esc_html__( 'This month', 'venissa' )
		),
		'active_callback'   => 'venissa_is_grid_posts_trending_checked'
	) );

	// Register Promo Box 1 setting
	$wp_customize->add_setting( 'venissa_promo_one', array(
		'default'           => '',
		'sanitize_callback' => 'esc_attr'
	) );
	$wp_customize->add_control( new Venissa_Custom_Title_Control( $wp_customize, 'venissa_promo_one', array(
		'label'             => esc_html__( 'PROMO BOX 1', 'venissa' ),
		'section'           => 'venissa_after_featured_posts',
		'priority'          => 21,
		'active_callback'   => 'venissa_is_promo_boxes_checked'
	) ) );

		$wp_customize->add_setting( 'venissa_promobox_one_img', array(
			'default'           => '',
			'sanitize_callback' => 'absint'
		) );
		$wp_customize->add_control( new WP_Customize_Media_Control( $wp_customize, 'venissa_promobox_one_img', array(
			'label'             => esc_html__( 'Image', 'venissa' ),
			'section'           => 'venissa_after_featured_posts',
			'priority'          => 23,
			'mime_type'         => 'image',
			'active_callback'   => 'venissa_is_promo_boxes_checked'
		) ) );

		$wp_customize->add_setting( 'venissa_promobox_one_url', array(
			'default'           => '',
			'sanitize_callback' => 'venissa_sanitize_url',
		) );
		$wp_customize->add_control( 'venissa_promobox_one_url', array(
			'label'             => esc_html__( 'URL', 'venissa' ),
			'section'           => 'venissa_after_featured_posts',
			'priority'          => 25,
			'type'              => 'url',
			'active_callback'   => 'venissa_is_promo_boxes_checked'
		) );

		$wp_customize->add_setting( 'venissa_promobox_one_text', array(
			'default'           => '',
			'sanitize_callback' => 'venissa_sanitize_html',
		) );
		$wp_customize->add_control( 'venissa_promobox_one_text', array(
			'label'             => esc_html__( 'Text', 'venissa' ),
			'section'           => 'venissa_after_featured_posts',
			'priority'          => 27,
			'type'              => 'text',
			'active_callback'   => 'venissa_is_promo_boxes_checked'
		) );

	// Register Promo Box 2 setting
	$wp_customize->add_setting( 'venissa_promo_two', array(
		'default'           => '',
		'sanitize_callback' => 'esc_attr'
	) );
	$wp_customize->add_control( new Venissa_Custom_Title_Control( $wp_customize, 'venissa_promo_two', array(
		'label'             => esc_html__( 'PROMO BOX 2', 'venissa' ),
		'section'           => 'venissa_after_featured_posts',
		'priority'          => 29,
		'active_callback'   => 'venissa_is_promo_boxes_checked'
	) ) );

		$wp_customize->add_setting( 'venissa_promobox_two_img', array(
			'default'           => '',
			'sanitize_callback' => 'absint'
		) );
		$wp_customize->add_control( new WP_Customize_Media_Control( $wp_customize, 'venissa_promobox_two_img', array(
			'label'             => esc_html__( 'Image', 'venissa' ),
			'section'           => 'venissa_after_featured_posts',
			'priority'          => 31,
			'mime_type'         => 'image',
			'active_callback'   => 'venissa_is_promo_boxes_checked'
		) ) );

		$wp_customize->add_setting( 'venissa_promobox_two_url', array(
			'default'           => '',
			'sanitize_callback' => 'venissa_sanitize_url',
		) );
		$wp_customize->add_control( 'venissa_promobox_two_url', array(
			'label'             => esc_html__( 'URL', 'venissa' ),
			'section'           => 'venissa_after_featured_posts',
			'priority'          => 33,
			'type'              => 'url',
			'active_callback'   => 'venissa_is_promo_boxes_checked'
		) );

		$wp_customize->add_setting( 'venissa_promobox_two_text', array(
			'default'           => '',
			'sanitize_callback' => 'venissa_sanitize_html',
		) );
		$wp_customize->add_control( 'venissa_promobox_two_text', array(
			'label'             => esc_html__( 'Text', 'venissa' ),
			'section'           => 'venissa_after_featured_posts',
			'priority'          => 35,
			'type'              => 'text',
			'active_callback'   => 'venissa_is_promo_boxes_checked'
		) );

	// Register Promo Box 3 setting
	$wp_customize->add_setting( 'venissa_promo_three', array(
		'default'           => '',
		'sanitize_callback' => 'esc_attr'
	) );
	$wp_customize->add_control( new Venissa_Custom_Title_Control( $wp_customize, 'venissa_promo_three', array(
		'label'             => esc_html__( 'PROMO BOX 3', 'venissa' ),
		'section'           => 'venissa_after_featured_posts',
		'priority'          => 37,
		'active_callback'   => 'venissa_is_promo_boxes_checked'
	) ) );

		$wp_customize->add_setting( 'venissa_promobox_three_img', array(
			'default'           => '',
			'sanitize_callback' => 'absint'
		) );
		$wp_customize->add_control( new WP_Customize_Media_Control( $wp_customize, 'venissa_promobox_three_img', array(
			'label'             => esc_html__( 'Image', 'venissa' ),
			'section'           => 'venissa_after_featured_posts',
			'priority'          => 39,
			'mime_type'         => 'image',
			'active_callback'   => 'venissa_is_promo_boxes_checked'
		) ) );

		$wp_customize->add_setting( 'venissa_promobox_three_url', array(
			'default'           => '',
			'sanitize_callback' => 'venissa_sanitize_url',
		) );
		$wp_customize->add_control( 'venissa_promobox_three_url', array(
			'label'             => esc_html__( 'URL', 'venissa' ),
			'section'           => 'venissa_after_featured_posts',
			'priority'          => 41,
			'type'              => 'url',
			'active_callback'   => 'venissa_is_promo_boxes_checked'
		) );

		$wp_customize->add_setting( 'venissa_promobox_three_text', array(
			'default'           => '',
			'sanitize_callback' => 'venissa_sanitize_html',
		) );
		$wp_customize->add_control( 'venissa_promobox_three_text', array(
			'label'             => esc_html__( 'Text', 'venissa' ),
			'section'           => 'venissa_after_featured_posts',
			'priority'          => 43,
			'type'              => 'text',
			'active_callback'   => 'venissa_is_promo_boxes_checked'
		) );

}
add_action( 'customize_register', 'venissa_after_featured_posts_customize_register' );

/**
 * Custom sanitization for multiple checkbox category.
 */
function venissa_sanitize_checkbox_multiple_category( $values ) {

	$multi_values = !is_array( $values ) ? explode( ',', $values ) : $values;

	return !empty( $multi_values ) ? array_map( 'absint', $multi_values ) : array();
}

/**
 * Enable after featured content
 */
function venissa_is_after_featured_posts_enable() {
	$enable = get_theme_mod( 'venissa_after_featured_posts_enable', 1 );

	if ( $enable ) {
		return true;
	} else {
		return false;
	}
}

/**
 * Featured category checked
 */
function venissa_is_featured_category_checked() {
	$content = get_theme_mod( 'venissa_after_featured_posts_content' );

	if ( $content == 'featured_category' ) {
		return true;
	} else {
		return false;
	}
}

/**
 * Subscribe form checked
 */
function venissa_is_subscribe_checked() {
	$content = get_theme_mod( 'venissa_after_featured_posts_content' );

	if ( $content == 'subscribe' ) {
		return true;
	} else {
		return false;
	}
}

/**
 * Grid posts checked
 */
function venissa_is_grid_posts_checked() {
	$content = get_theme_mod( 'venissa_after_featured_posts_content' );

	if ( $content == 'grid_posts' ) {
		return true;
	} else {
		return false;
	}
}

/**
 * Grid posts and trending query is checked
 */
function venissa_is_grid_posts_trending_checked() {
	$content = get_theme_mod( 'venissa_after_featured_posts_content' );
	$query   = get_theme_mod( 'venissa_grid_posts_query', 'popular' );

	if ( $content == 'grid_posts' && $query == 'trending' ) {
		return true;
	} else {
		return false;
	}
}

/**
 * Promo boxes checked
 */
function venissa_is_promo_boxes_checked() {
	$content = get_theme_mod( 'venissa_after_featured_posts_content' );

	if ( $content == 'promo_boxes' ) {
		return true;
	} else {
		return false;
	}
}

/**
 * Render the title.
 *
 * @return void
 */
function venissa_customize_partial_grid_posts_title() {
	return venissa_sanitize_html( get_theme_mod( 'venissa_grid_posts_title' ) );
}
