<?php
/**
 * Footer Customizer
 */

/**
 * Register the customizer.
 */
function venissa_footer_customize_register( $wp_customize ) {

	// Register new section: Footer
	$wp_customize->add_section( 'venissa_footer' , array(
		'title'    => esc_html__( 'Footer', 'venissa' ),
		'panel'    => 'venissa_options',
		'priority' => 21
	) );

	// Register footer branding setting
	$wp_customize->add_setting( 'venissa_footer_logo', array(
		'default'           => '',
		'sanitize_callback' => 'absint'
	) );
	$wp_customize->add_control( new WP_Customize_Cropped_Image_Control( $wp_customize, 'venissa_footer_logo', array(
		'label'             => esc_html__( 'Logo', 'venissa' ),
		'section'           => 'venissa_footer',
		'priority'          => 1,
		'flex_width'        => true,
		'flex_height'       => true,
		'width'             => 275,
		'height'            => 60
	) ) );

	// Register retina footer branding setting
	$wp_customize->add_setting( 'venissa_retina_footer_logo', array(
		'default'           => '',
		'sanitize_callback' => 'absint'
	) );
	$wp_customize->add_control( new WP_Customize_Cropped_Image_Control( $wp_customize, 'venissa_retina_footer_logo', array(
		'label'             => esc_html__( 'Retina Logo', 'venissa' ),
		'section'           => 'venissa_footer',
		'priority'          => 3,
		'flex_width'        => true,
		'flex_height'       => true,
		'width'             => 500,
		'height'            => 140
	) ) );

	// Register footer background color setting
	$wp_customize->add_setting( 'venissa_footer_bg_color', array(
		'default'           => '#1e1e1e',
		'sanitize_callback' => 'venissa_sanitize_hex_color',
		'transport'         => 'postMessage'
	) );
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'venissa_footer_bg_color', array(
		'label'             => esc_html__( 'Background color', 'venissa' ),
		'section'           => 'venissa_footer',
		'priority'          => 7
	) ) );

	// Register footer widget column setting
	$wp_customize->add_setting( 'venissa_footer_widget_column', array(
		'default'           => '3',
		'sanitize_callback' => 'venissa_sanitize_select',
	) );
	$wp_customize->add_control( 'venissa_footer_widget_column', array(
		'label'             => esc_html__( 'Footer Widget Columns', 'venissa' ),
		'section'           => 'venissa_footer',
		'priority'          => 9,
		'type'              => 'radio',
		'choices'           => array(
			'3' => esc_html__( '3 Columns', 'venissa' ),
			'4' => esc_html__( '4 Columns', 'venissa' )
		)
	) );

	// Register Footer Credits setting
	$wp_customize->add_setting( 'venissa_footer_credits', array(
		'sanitize_callback' => 'venissa_sanitize_html',
		'default'           => '&copy; Copyright ' . date( 'Y' ) . ' - <a href="' . esc_url( home_url() ) . '">' . esc_attr( get_bloginfo( 'name' ) ) . '</a>. All Rights Reserved. <br /> Designed & Developed by <a href="https://www.theme-junkie.com/">Theme Junkie</a>',
		'transport'         => 'postMessage',
	) );
	$wp_customize->add_control( 'venissa_footer_credits', array(
		'label'             => esc_html__( 'Footer Text', 'venissa' ),
		'section'           => 'venissa_footer',
		'priority'          => 11,
		'type'              => 'textarea'
	) );
	if ( isset( $wp_customize->selective_refresh ) ) {
		$wp_customize->selective_refresh->add_partial( 'venissa_footer_credits', array(
			'selector'         => '.copyright',
			'settings'         => array( 'venissa_footer_credits' ),
			'render_callback'  => 'venissa_customize_partial_footer_credits'
		) );
	}

}
add_action( 'customize_register', 'venissa_footer_customize_register' );

/**
 * Render the footer credits.
 *
 * @return void
 */
function venissa_customize_partial_footer_credits() {
	return venissa_sanitize_html( get_theme_mod( 'venissa_footer_credits' ) );
}
