<?php
/**
 * Post Customizer
 */

/**
 * Register the customizer.
 */
function venissa_post_customize_register( $wp_customize ) {

	// Register new section: Post
	$wp_customize->add_section( 'venissa_post' , array(
		'title'       => esc_html__( 'Posts', 'venissa' ),
		'description' => esc_html__( 'These options are for customizing the single post.', 'venissa' ),
		'panel'       => 'venissa_options',
		'priority'    => 15
	) );

	// Register post layouts setting
	$wp_customize->add_setting( 'venissa_post_layouts', array(
		'default'           => 'right-sidebar',
		'sanitize_callback' => 'venissa_sanitize_select',
	) );
	$wp_customize->add_control( 'venissa_post_layouts', array(
		'label'             => esc_html__( 'Post Layout', 'venissa' ),
		'description'       => esc_html__( 'This setting will change all posts layout.', 'venissa' ),
		'section'           => 'venissa_post',
		'priority'          => 1,
		'type'              => 'radio',
		'choices'           => array(
			'right-sidebar'     => esc_html__( 'Right sidebar', 'venissa' ),
			'left-sidebar'      => esc_html__( 'Left sidebar', 'venissa' ),
			'full-width'        => esc_html__( 'Full width', 'venissa' ),
			'full-width-narrow' => esc_html__( 'Full width narrow', 'venissa' ),
		),
	) );

	// Register post tags setting
	$wp_customize->add_setting( 'venissa_post_tags', array(
		'default'           => 1,
		'sanitize_callback' => 'venissa_sanitize_checkbox',
	) );
	$wp_customize->add_control( 'venissa_post_tags', array(
		'label'             => esc_html__( 'Enable tags', 'venissa' ),
		'section'           => 'venissa_post',
		'priority'          => 3,
		'type'              => 'checkbox'
	) );

	// Register post tags title setting
	$wp_customize->add_setting( 'venissa_post_tags_title', array(
		'default'           => esc_html__( 'Topics', 'venissa' ),
		'sanitize_callback' => 'venissa_sanitize_html',
		'transport'         => 'postMessage'
	) );
	$wp_customize->add_control( 'venissa_post_tags_title', array(
		'label'             => esc_html__( 'Post tags title', 'venissa' ),
		'section'           => 'venissa_post',
		'priority'          => 5,
		'type'              => 'text',
		'active_callback'   => 'venissa_is_post_tags_checked'
	) );
	if ( isset( $wp_customize->selective_refresh ) ) {
		$wp_customize->selective_refresh->add_partial( 'venissa_post_tags_title', array(
			'selector'         => '.tag-title',
			'settings'         => array( 'venissa_post_tags_title' ),
			'render_callback'  => 'venissa_customize_partial_tags_title'
		) );
	}

	// Register Author Box setting
	$wp_customize->add_setting( 'venissa_author_box', array(
		'default'           => 1,
		'sanitize_callback' => 'venissa_sanitize_checkbox',
	) );
	$wp_customize->add_control( 'venissa_author_box', array(
		'label'             => esc_html__( 'Enable author box', 'venissa' ),
		'section'           => 'venissa_post',
		'priority'          => 7,
		'type'              => 'checkbox'
	) );

	// Register Next & Prev post setting
	$wp_customize->add_setting( 'venissa_next_prev_post', array(
		'default'           => 1,
		'sanitize_callback' => 'venissa_sanitize_checkbox',
	) );
	$wp_customize->add_control( 'venissa_next_prev_post', array(
		'label'             => esc_html__( 'Enable next & prev post', 'venissa' ),
		'section'           => 'venissa_post',
		'priority'          => 9,
		'type'              => 'checkbox'
	) );

	// Register Post Share setting
	$wp_customize->add_setting( 'venissa_post_share', array(
		'default'           => 1,
		'sanitize_callback' => 'venissa_sanitize_checkbox',
	) );
	$wp_customize->add_control( 'venissa_post_share', array(
		'label'             => esc_html__( 'Enable share buttons', 'venissa' ),
		'section'           => 'venissa_post',
		'priority'          => 11,
		'type'              => 'checkbox'
	) );

	// Register Related Posts setting
	$wp_customize->add_setting( 'venissa_related_posts', array(
		'default'           => 1,
		'sanitize_callback' => 'venissa_sanitize_checkbox',
	) );
	$wp_customize->add_control( 'venissa_related_posts', array(
		'label'             => esc_html__( 'Enable related posts', 'venissa' ),
		'section'           => 'venissa_post',
		'priority'          => 13,
		'type'              => 'checkbox'
	) );

	// Register Related posts title setting
	$wp_customize->add_setting( 'venissa_related_posts_title', array(
		'default'           => esc_html__( 'You Might Also Like', 'venissa' ),
		'sanitize_callback' => 'venissa_sanitize_html',
		'transport'         => 'postMessage'
	) );
	$wp_customize->add_control( 'venissa_related_posts_title', array(
		'label'             => esc_html__( 'Related posts title', 'venissa' ),
		'section'           => 'venissa_post',
		'priority'          => 15,
		'type'              => 'text',
		'active_callback'   => 'venissa_is_related_posts_checked'
	) );
	if ( isset( $wp_customize->selective_refresh ) ) {
		$wp_customize->selective_refresh->add_partial( 'venissa_related_posts_title', array(
			'selector'         => '.related-posts-title',
			'settings'         => array( 'venissa_related_posts_title' ),
			'render_callback'  => 'venissa_customize_partial_related_posts_title'
		) );
	}

	// Register Related posts title setting
	$wp_customize->add_setting( 'venissa_related_posts_number', array(
		'default'           => 5,
		'sanitize_callback' => 'absint',
	) );
	$wp_customize->add_control( 'venissa_related_posts_number', array(
		'label'             => esc_html__( 'Related posts number', 'venissa' ),
		'description'       => esc_html__( 'The number of posts you want to show.', 'venissa' ),
		'section'           => 'venissa_post',
		'priority'          => 17,
		'type'              => 'number',
		'input_attrs'       => array(
			'min'  => 0,
			'step' => 1
		),
		'active_callback'   => 'venissa_is_related_posts_checked'
	) );

	// Register Post comment manager setting
	$wp_customize->add_setting( 'venissa_post_comment', array(
		'default'           => 1,
		'sanitize_callback' => 'venissa_sanitize_checkbox',
	) );
	$wp_customize->add_control( 'venissa_post_comment', array(
		'label'             => esc_html__( 'Enable comment on post', 'venissa' ),
		'section'           => 'venissa_post',
		'priority'          => 19,
		'type'              => 'checkbox'
	) );

}
add_action( 'customize_register', 'venissa_post_customize_register' );

/**
 * Active callback when Post Tags checked.
 */
function venissa_is_post_tags_checked() {
	$tags = get_theme_mod( 'venissa_post_tags', 1 );

	if ( $tags ) {
		return true;
	} else {
		return false;
	}
}

/**
 * Active callback when Related Posts checked.
 */
function venissa_is_related_posts_checked() {
	$related = get_theme_mod( 'venissa_related_posts', 1 );

	if ( $related ) {
		return true;
	} else {
		return false;
	}
}

/**
 * Render the tags title.
 *
 * @return void
 */
function venissa_customize_partial_tags_title() {
	return venissa_sanitize_html( get_theme_mod( 'venissa_post_tags_title' ) );
}

/**
 * Render the related posts title.
 *
 * @return void
 */
function venissa_customize_partial_related_posts_title() {
	return venissa_sanitize_html( get_theme_mod( 'venissa_related_posts_title' ) );
}
