<?php
/**
 * Posts Carousel Customizer
 */

/**
 * Register the customizer.
 */
function venissa_posts_carousel_customize_register( $wp_customize ) {

	// Register new section: Posts Carousel
	$wp_customize->add_section( 'venissa_posts_carousel' , array(
		'title'       => esc_html__( 'Posts Carousel', 'venissa' ),
		'description' => esc_html__( 'Posts carousel is a list of posts appear on the footer of your site.', 'venissa' ),
		'panel'       => 'venissa_options',
		'priority'    => 19
	) );

	// Register enable posts carousel setting
	$wp_customize->add_setting( 'venissa_posts_carousel_enable', array(
		'default'           => 1,
		'sanitize_callback' => 'venissa_sanitize_checkbox',
	) );
	$wp_customize->add_control( 'venissa_posts_carousel_enable', array(
		'label'             => esc_html__( 'Show posts carousel posts', 'venissa' ),
		'section'           => 'venissa_posts_carousel',
		'priority'          => 1,
		'type'              => 'checkbox'
	) );

	// Register title setting
	$wp_customize->add_setting( 'venissa_posts_carousel_title', array(
		'default'           => esc_html__( 'Trending Now', 'venissa' ),
		'sanitize_callback' => 'venissa_sanitize_html',
		'transport'         => 'postMessage',
	) );
	$wp_customize->add_control( 'venissa_posts_carousel_title', array(
		'label'             => esc_html__( 'Title', 'venissa' ),
		'section'           => 'venissa_posts_carousel',
		'priority'          => 7,
		'type'              => 'text'
	) );
	if ( isset( $wp_customize->selective_refresh ) ) {
		$wp_customize->selective_refresh->add_partial( 'venissa_posts_carousel_title', array(
			'selector'         => '.posts_carousel-title',
			'settings'         => array( 'venissa_posts_carousel_title' ),
			'render_callback'  => 'venissa_customize_partial_posts_carousel_title'
		) );
	}

	// Register query setting
	$wp_customize->add_setting( 'venissa_posts_carousel_query', array(
		'default'           => 'trending',
		'sanitize_callback' => 'venissa_sanitize_select'
	) );
	$wp_customize->add_control( 'venissa_posts_carousel_query', array(
		'label'             => esc_html__( 'Query', 'venissa' ),
		'section'           => 'venissa_posts_carousel',
		'priority'          => 9,
		'type'              => 'radio',
		'choices'           => array(
			'trending' => esc_html__( 'Trending', 'venissa' ),
			'recent'   => esc_html__( 'Most recent', 'venissa' ),
			'popular'  => esc_html__( 'Popular by comment', 'venissa' ),
			'random'   => esc_html__( 'Random', 'venissa' )
		)
	) );

	// Register posts carousel time setting
	$wp_customize->add_setting( 'venissa_posts_carousel_time', array(
		'default'           => 'all',
		'sanitize_callback' => 'venissa_sanitize_select',
	) );
	$wp_customize->add_control( 'venissa_posts_carousel_time', array(
		'label'             => esc_html__( 'Time', 'venissa' ),
		'section'           => 'venissa_posts_carousel',
		'priority'          => 11,
		'type'              => 'radio',
		'choices'           => array(
			'all'   => esc_html__( 'All time', 'venissa' ),
			'today' => esc_html__( 'Today', 'venissa' ),
			'week'  => esc_html__( 'This week', 'venissa' ),
			'month' => esc_html__( 'This month', 'venissa' )
		),
		'active_callback'   => 'venissa_is_posts_carousel_checked'
	) );

	// Register number setting
	$wp_customize->add_setting( 'venissa_posts_carousel_number', array(
		'default'           => 8,
		'sanitize_callback' => 'absint',
	) );
	$wp_customize->add_control( 'venissa_posts_carousel_number', array(
		'label'             => esc_html__( 'Number', 'venissa' ),
		'description'       => esc_html__( 'The number of posts you want to show.', 'venissa' ),
		'section'           => 'venissa_posts_carousel',
		'priority'          => 13,
		'type'              => 'number',
		'input_attrs'       => array(
			'min'  => 0,
			'step' => 1
		)
	) );

}
add_action( 'customize_register', 'venissa_posts_carousel_customize_register' );

/**
 * Trending posts is checked.
 */
function venissa_is_posts_carousel_checked() {
	$query = get_theme_mod( 'venissa_posts_carousel_query', 'trending' );

	if ( $query == 'trending' ) {
		return true;
	} else {
		return false;
	}
}

/**
 * Render the posts carousel title.
 *
 * @return void
 */
function venissa_customize_partial_posts_carousel_title() {
	return venissa_sanitize_html( get_theme_mod( 'venissa_posts_carousel_title' ) );
}
